@@ -1,28 +1,25 @@
-import glob
-
 try:
     import networkx as nx
+    from networkx.drawing.nx_agraph import graphviz_layout
     import matplotlib.pyplot as plt
     _DRAW_GRAPHS = True
-except:
+except Exception:
     _DRAW_GRAPHS = False
 
-import json
-
 from . import schema
 from .jsonutil import get_column
 from .search import Search
-from .uriutil import check_entry
+
 
 class Inspector(object):
     """ Database introspection interface.
     """
 
     def __init__(self, interface):
-        """ 
+        """
             Parameters
             ----------
-            interface: 
+            interface:
                 :class:`Interface` Object
         """
         self._intf = interface
@@ -40,6 +37,7 @@ class Inspector(object):
         """ Once in a while queries will persist additional
             information on the server. This information is available
             through the following methods of this class:
+
                 - experiment_types
                 - assessor_types
                 - scan_types
@@ -57,7 +55,7 @@ class Inspector(object):
 
             See Also
             --------
-            EObject.insert()
+            :func:`EObject.insert`
         """
         if auto is not None:
             self._auto = auto
@@ -72,93 +70,91 @@ class Inspector(object):
             pattern: string
                 Pattern for the datatype. May include wildcards.
             fields_pattern: string
-                - Pattern for the datafields -- may include wildcards. 
+                - Pattern for the datafields -- may include wildcards.
                 - If specified, datafields will be returned instead of
                   datatypes.
-                
+
             Returns
             -------
             list : datatypes or datafields depending on the argument usage.
         """
         self._intf._get_entry_point()
 
-        search_els = self._get_json('%s/search/elements?format=json' % 
-                                        self._intf._get_entry_point())
+        search_els = self._get_json('%s/search/elements?format=json' %
+                                    self._intf._get_entry_point())
 
-        if not fields_pattern and ('*' in pattern or '?' in pattern):       
-            return get_column(search_els , 'ELEMENT_NAME', pattern)
+        if not fields_pattern and ('*' in pattern or '?' in pattern):
+            return get_column(search_els, 'ELEMENT_NAME', pattern)
 
         else:
             fields = []
-            for datatype in get_column(search_els , 'ELEMENT_NAME', pattern):
-                fields.extend(self._datafields(datatype, 
-                                               fields_pattern or '*', True)
-                              )
+            for datatype in get_column(search_els, 'ELEMENT_NAME', pattern):
+                df = self._datafields(datatype, fields_pattern or '*', True)
+                fields.extend(df)
 
             return fields
 
     def _datafields(self, datatype, pattern='*', prepend_type=True):
         self._intf._get_entry_point()
 
-        search_fds = self._get_json('%s/search/elements/%s?format=json'
-                                        % (self._intf._get_entry_point(), datatype)
-                                    )
+        search_fds = self._get_json('%s/search/elements/%s?format=json' %
+                                    (self._intf._get_entry_point(),
+                                        datatype))
 
         fields = get_column(search_fds, 'FIELD_ID', pattern)
 
-        return ['%s/%s' % (datatype, field) 
+        return ['%s/%s' % (datatype, field)
                 if prepend_type else field
-                for field in fields 
+                for field in fields
                 if '=' not in field and 'SHARINGSHAREPROJECT' not in field
                 ]
 
     def experiment_types(self):
-        """ Returns the datatypes used at the experiment level in this 
+        """ Returns the datatypes used at the experiment level in this
             database.
-            
+
             See Also
             --------
-            Inspector.set_autolearn()
+            :func:`Inspector.set_autolearn`
         """
         return self._resource_types('experiment')
 
     def assessor_types(self):
-        """ Returns the datatypes used at the assessor level in this 
+        """ Returns the datatypes used at the assessor level in this
             database.
-            
+
             See Also
             --------
-            Inspector.set_autolearn()
+            :func:`Inspector.set_autolearn`
         """
         return self._resource_types('assessor')
 
     def reconstruction_types(self):
-        """ Returns the datatypes used at the reconstruction level in this 
+        """ Returns the datatypes used at the reconstruction level in this
             database.
-            
+
             See Also
             --------
-            Inspector.set_autolearn()
+            :func:`Inspector.set_autolearn`
         """
         return self._resource_types('reconstruction')
 
     def scan_types(self):
-        """ Returns the datatypes used at the scan level in this 
+        """ Returns the datatypes used at the scan level in this
             database.
-            
+
             See Also
             --------
-            Inspector.set_autolearn()
+            :func:`Inspector.set_autolearn`
         """
         return self._resource_types('scan')
 
-
     def field_values(self, field_name):
-        """ Look for the values a specific datafield takes in the database. 
+        """ Look for the values a specific datafield takes in the database.
         """
         self._intf._get_entry_point()
 
-        search_tbl = Search(field_name.split('/')[0], 
+        search_tbl = Search(field_name.split('/')[0],
                             [field_name], self._intf
                             )
 
@@ -200,7 +196,7 @@ class Inspector(object):
         """ Look for the values a the experiment level for a given datatype
             in the database.
 
-            .. note:: 
+            .. note::
                 The  datatype should be one of Inspector.experiment_types()
 
             Parameters
@@ -225,7 +221,7 @@ class Inspector(object):
             type in the database.
 
             .. note::
-               The experiment type should be one of 
+               The experiment type should be one of
                Inspector.experiment_types()
 
             .. warning::
@@ -239,7 +235,7 @@ class Inspector(object):
             project: string
                 Optional. Restrict operation to a project.
         """
-        return self._sub_experiment_values('assessor', 
+        return self._sub_experiment_values('assessor',
                                            project, experiment_type)
 
     def scan_values(self, experiment_type, project=None):
@@ -247,7 +243,7 @@ class Inspector(object):
             type in the database.
 
             .. note::
-               The experiment type should be one of 
+               The experiment type should be one of
                Inspector.experiment_types()
 
             .. warning::
@@ -264,11 +260,11 @@ class Inspector(object):
         return self._sub_experiment_values('scan', project, experiment_type)
 
     def reconstruction_values(self, experiment_type, project=None):
-        """ Look for the values at the reconstruction level for a given 
+        """ Look for the values at the reconstruction level for a given
             experiment type in the database.
 
             .. note::
-               The experiment type should be one of 
+               The experiment type should be one of
                Inspector.experiment_types()
 
             .. warning::
@@ -282,7 +278,7 @@ class Inspector(object):
             project: string
                 Optional. Restrict operation to a project.
         """
-        return self._sub_experiment_values('reconstruction', 
+        return self._sub_experiment_values('reconstruction',
                                            project, experiment_type)
 
     def structure(self):
@@ -290,7 +286,7 @@ class Inspector(object):
         """
         def traverse(coll, lvl):
             for key in schema.resources_tree[coll]:
-                print('%s+%s') % (' ' * lvl, key.upper())
+                print('%s+%s' % (' ' * lvl, key.upper()))
 
                 datatypes = set([
                         self._intf._struct[uri]
@@ -299,15 +295,15 @@ class Inspector(object):
                         ])
 
                 if datatypes != set():
-                    print('%s  %s') % (' ' * lvl, '-' * len(key))
+                    print('%s  %s' % (' ' * lvl, '-' * len(key)))
 
                 for datatype in datatypes:
-                    print('%s- %s') % (' ' * lvl, datatype)
+                    print('%s- %s' % (' ' * lvl, datatype))
 
-                if schema.resources_tree.has_key(key):
+                if key in schema.resources_tree.keys():
                     traverse(key, lvl + 4)
 
-        print('- %s') % 'PROJECTS'
+        print('- %s' % 'PROJECTS')
         traverse('projects', 4)
 
     def _sub_experiment_values(self, sub_exp, project, experiment_type):
@@ -317,8 +313,8 @@ class Inspector(object):
 
         column = '%s/%ss/%s/id' % \
             (experiment_type.lower(), sub_exp, sub_exp)
-        
-        sub_exps = '%s/experiments?columns=ID,%s' % (self._intf._entry, 
+
+        sub_exps = '%s/experiments?columns=ID,%s' % (self._intf._entry,
                                                      column
                                                      )
 
@@ -330,9 +326,9 @@ class Inspector(object):
         return list(set(values))
 
     def _resource_struct(self, name):
-        
+
         return self._intf._struct
-    
+
     def _resource_types(self, name):
         return list(set(self._resource_struct(name).values()))
 
@@ -343,8 +339,8 @@ class GraphData(object):
         self._struct = interface._struct
 
     # def link(self, subjects, fields):
-        
-    #     criteria = [('xnat:subjectData/SUBJECT_ID', '=', _id) 
+
+    #     criteria = [('xnat:subjectData/SUBJECT_ID', '=', _id)
     #                 for _id in subjects
     #                 ]
     #     criteria += ['OR']
@@ -354,7 +350,7 @@ class GraphData(object):
 
     #     for field in fields:
 
-    #         field_tbl = self._intf.select('xnat:subjectData', 
+    #         field_tbl = self._intf.select('xnat:subjectData',
     #                                       [subject_id, field]
     #                                       ).where(criteria)
     #         head = field_tbl.headers()
@@ -363,7 +359,7 @@ class GraphData(object):
     #         possible = set(field_tbl.get(head))
 
     #         groups = {}
-            
+
     #         for val in possible:
     #             groups[val] = field_tbl.where(**{head:val}
     #                                             ).select('subject_id')
@@ -373,12 +369,12 @@ class GraphData(object):
     def datatypes(self, pattern='*'):
         graph = nx.DiGraph()
         graph.add_node('datatypes')
-        graph.labels = {'datatypes':'datatypes'}
-        graph.weights = {'datatypes':100.0}
-        
+        graph.labels = {'datatypes': 'datatypes'}
+        graph.weights = {'datatypes': 100.0}
+
         datatypes = self._intf.inspect.datatypes(pattern)
         namespaces = set([dat.split(':')[0] for dat in datatypes])
-        
+
         for ns in namespaces:
             graph.add_edge('datatypes', ns)
             graph.weights[ns] = 70.0
@@ -395,11 +391,11 @@ class GraphData(object):
 
         graph = nx.DiGraph()
         graph.add_node(name)
-        graph.labels = {name:name}
-        graph.weights = {name:100.0}
-        
+        graph.labels = {name: name}
+        graph.weights = {name: 100.0}
+
         namespaces = set([exp.split(':')[0] for exp in resource_types])
-        
+
         for ns in namespaces:
             graph.add_edge(name, ns)
             graph.weights[ns] = 70.0
@@ -412,8 +408,8 @@ class GraphData(object):
         return graph
 
     def field_values(self, field_name):
-        
-        search_tbl = Search(field_name.split('/')[0], 
+
+        search_tbl = Search(field_name.split('/')[0],
                             [field_name], self._intf
                             )
 
@@ -439,8 +435,8 @@ class GraphData(object):
     def architecture(self, with_datatypes=True):
         graph = nx.DiGraph()
         graph.add_node('projects')
-        graph.labels = {'projects':'projects'}
-        graph.weights = {'projects':100.0}
+        graph.labels = {'projects': 'projects'}
+        graph.weights = {'projects': 100.0}
 
         def traverse(lkw, as_lkw):
 
@@ -474,8 +470,8 @@ class PaintGraph(object):
     def architecture(self, with_datatypes=True, save=None):
         graph = self.get_graph.architecture(with_datatypes)
 
-        plt.figure(figsize=(8,8))
-        pos = nx.graphviz_layout(graph, prog='twopi', args='')
+        plt.figure(figsize=(8, 8))
+        pos = graphviz_layout(graph, prog='twopi', args='')
 
         # node_size = [(float(graph.degree(v)) * 5)**3 for v in graph]
         # node_size = [graph.weights[v] ** 2 for v in graph]
@@ -487,12 +483,12 @@ class PaintGraph(object):
 
         costs = norm_costs([cost(v) for v in graph], 10000)
 
-        nx.draw(graph, pos, labels=graph.labels, 
+        nx.draw(graph, pos, labels=graph.labels,
                 node_size=costs, node_color=costs,
-                font_size=13, font_color='orange', 
+                font_size=13, font_color='orange',
                 font_weight='bold', with_labels=True
                 )
-    
+
         plt.axis('off')
 
         if save is not None:
@@ -517,8 +513,8 @@ class PaintGraph(object):
         self._draw_rest_resource(graph)
 
     def _draw_rest_resource(self, graph, save=None):
-        plt.figure(figsize=(8,8))
-        pos = nx.graphviz_layout(graph, prog='twopi', args='')
+        plt.figure(figsize=(8, 8))
+        pos = graphviz_layout(graph, prog='twopi', args='')
 
         cost = lambda v: float(graph.degree(v)) ** 3 + \
             graph.weights[v] ** 2
@@ -528,23 +524,23 @@ class PaintGraph(object):
         # node_color = [float(graph.degree(v)) for v in graph]
         node_color = [cost(v) for v in graph]
 
-        nx.draw(graph, pos, 
+        nx.draw(graph, pos,
                 node_size=node_size, node_color=node_color,
                 font_size=13, font_color='green', font_weight='bold'
                 )
-    
+
         plt.axis('off')
 
         if save is not None:
             plt.savefig(save)
 
         plt.show()
-        
+
     def datatypes(self, pattern='*', save=None):
         graph = self.get_graph.datatypes(pattern)
 
-        plt.figure(figsize=(8,8))
-        pos = nx.graphviz_layout(graph, prog='twopi', args='')
+        plt.figure(figsize=(8, 8))
+        pos = graphviz_layout(graph, prog='twopi', args='')
 
         cost = lambda v: float(graph.degree(v)) ** 3 + \
             graph.weights[v] ** 2
@@ -554,12 +550,12 @@ class PaintGraph(object):
         # node_color = [float(graph.degree(v)) for v in graph]
         node_color = [cost(v) for v in graph]
 
-        nx.draw(graph, pos, 
+        nx.draw(graph, pos,
                 node_size=node_size, node_color=node_color,
                 font_size=13, font_color='green', font_weight='bold',
                 with_labels=True
                 )
-    
+
         plt.axis('off')
 
         if save is not None:
@@ -570,8 +566,8 @@ class PaintGraph(object):
     def field_values(self, field_name, save=None):
         graph = self.get_graph.field_values(field_name)
 
-        plt.figure(figsize=(8,8))
-        pos = nx.graphviz_layout(graph, prog='twopi', args='')
+        plt.figure(figsize=(8, 8))
+        pos = graphviz_layout(graph, prog='twopi', args='')
 
         cost = lambda v: graph.weights[v]
 
@@ -579,12 +575,12 @@ class PaintGraph(object):
 
         costs = norm_costs([cost(v) for v in graph], 10000)
 
-        nx.draw(graph, pos, 
+        nx.draw(graph, pos,
                 node_size=costs, node_color=costs,
-                font_size=13, font_color='black', 
+                font_size=13, font_color='black',
                 font_weight='bold', with_labels=True
                 )
-    
+
         plt.axis('off')
 
         if save is not None:
@@ -596,9 +592,9 @@ class PaintGraph(object):
 def norm_costs(costs, norm=1000):
     max_cost = max(costs)
 
-    return [ (cost / max_cost) * norm for cost in costs]
+    return [(cost / max_cost) * norm for cost in costs]
+
 
-    
 # class GraphDrawer(object):
 #     def __init__(self, interface):
 #         self._intf = interface
@@ -620,26 +616,26 @@ def norm_costs(costs, norm=1000):
 
 #         pos = nx.graphviz_layout(g, prog='twopi', args='')
 
-#         nx.draw_networkx_nodes(g, pos, 
-#                                nodelist=[project], 
-#                                node_color='green', alpha=0.7, 
+#         nx.draw_networkx_nodes(g, pos,
+#                                nodelist=[project],
+#                                node_color='green', alpha=0.7,
 #                                node_size=2500, node_shape='s')
 
-#         nx.draw_networkx_nodes(g, pos, 
-#                                nodelist=['Experiments'], 
-#                                node_color='blue', alpha=0.7, 
+#         nx.draw_networkx_nodes(g, pos,
+#                                nodelist=['Experiments'],
+#                                node_color='blue', alpha=0.7,
 #                                node_size=2000, node_shape='p')
 
-#         nx.draw_networkx_nodes(g, pos, 
-#                                nodelist=experiments_types, 
-#                                node_color='red', alpha=0.7, 
+#         nx.draw_networkx_nodes(g, pos,
+#                                nodelist=experiments_types,
+#                                node_color='red', alpha=0.7,
 #                                node_size=1500, node_shape='o')
 
-#         nx.draw_networkx_edges(g, pos, width=2, alpha=0.5, 
+#         nx.draw_networkx_edges(g, pos, width=2, alpha=0.5,
 #                                edge_color='black')
 
 #         nx.draw_networkx_labels(g, pos, labels,
-#                                 alpha=0.9, font_size=8, 
+#                                 alpha=0.9, font_size=8,
 #                                 font_color='black', font_weight='bold')
 
 #         plt.axis('off')
@@ -652,24 +648,23 @@ class SchemasInspector(object):
         self._intf = interface
 
     def __call__(self):
-        self._intf.manage.schemas._init()
+        self._intf.manage.schemas()
 
         for xsd in self._intf.manage.schemas():
             print('-'*40)
             print(xsd.upper())
             print('-'*40)
-            print
+            print()
 
-            for datatype in schema.datatypes(
-                self._intf.manage.schemas._trees[xsd]):
+            trees = self._intf.manage.schemas._trees[xsd]
+            for datatype in schema.datatypes(trees):
                 print('[%s]' % datatype)
-                print
+                print()
 
-                for path in schema.datatype_attributes(
-                    self._intf.manage.schemas._trees[xsd], datatype):
+                for path in schema.datatype_attributes(trees, datatype):
                     print(path)
 
-                print
+                print()
 
     def look_for(self, element_name, datatype_name=None):
         paths = []
@@ -680,21 +675,17 @@ class SchemasInspector(object):
                 paths.extend(schema.datatype_attributes(root, element_name))
             return paths
 
-        for xsd in self._intf.manage.schemas(): 
+        for xsd in self._intf.manage.schemas():
             # nsmap = self._intf.manage.schemas._trees[xsd].nsmap
-
+            trees = self._intf.manage.schemas._trees[xsd]
             if datatype_name is not None:
                 datatypes = [datatype_name]
             else:
-                datatypes = schema.datatypes(
-                    self._intf.manage.schemas._trees[xsd]
-                    )
+                datatypes = schema.datatypes(trees)
 
             for datatype in datatypes:
-                for path in schema.datatype_attributes(
-                    self._intf.manage.schemas._trees[xsd], datatype):
+                for path in schema.datatype_attributes(trees, datatype):
                     if element_name in path:
                         paths.append(path)
 
         return paths
-
